@@ -715,7 +715,7 @@ class TestProperty(unittest.TestCase):
         self.assertEqual(b.prop1, 20)
 
     def test_property_subclass_c(self):
-        class A(GIMarshallingTests.PropertiesObject):
+        class A(Regress.TestSubObj):
             prop1 = GObject.Property(type=int)
 
         a = A()
@@ -723,8 +723,15 @@ class TestProperty(unittest.TestCase):
         self.assertEqual(a.prop1, 10)
 
         # also has parent properties
-        a.props.some_int = 20
-        self.assertEqual(a.props.some_int, 20)
+        a.props.int = 20
+        self.assertEqual(a.props.int, 20)
+
+        # Some of which are unusable without introspection
+        a.props.list = ("str1", "str2")
+        self.assertEqual(a.props.list, ["str1", "str2"])
+
+        a.set_property("list", ("str3", "str4"))
+        self.assertEqual(a.props.list, ["str3", "str4"])
 
     def test_property_subclass_custom_setter(self):
         # test for #523352
